/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""

]
, "Application, Applications"
: [
  "one: Ứng dụng\nother: Ứng dụng"

]
, "User, Users"
: [
  "one: Người dùng\nother: Người dùng"

]
, "Groups"
: "Nhóm"

, "Roles"
: "Vai trò"

, "Applications"
: "Ứng dụng"

, "Containers"
: "Bộ chứa"

, "Shared Tags"
: "Từ khóa chia sẻ"

, "Customfields"
: "Trường tùy biến"

, "Computers"
: "Máy tính"

, "Access Log, Access Logs"
: [
  "one: Nhật ký truy cập\nother: Nhật ký truy cập"

]
, "Log"
: ""

, "Server Information"
: "Thông tin máy chủ"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Admin"

, "Refresh"
: "Nạp lại"

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: "Danh bạ mặc định cho nhóm và liên lạc mới"

, "Computer Name"
: "Tên máy tính"

, "Config, Configs"
: [
  ""

]
, "Description"
: "Mô tả"

, "Name"
: "Tên"

, "Label"
: "Nhãn"

, "Value"
: "Giá trị"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "Tên nhóm"

, "Visibility"
: "Có thể nhìn thấy"

, "Display in addressbook"
: "Hiển thị trong sổ địa chỉ"

, "Hide from addressbook"
: "Ẩn từ sổ địa chỉ"

, "Saved in Addressbook"
: "Đã lưu trong Sổ địa chỉ"

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Nhóm thành viên"

, "Domain is not allowed. Check your SMTP domain configuration."
: "Tên miền không được phép. Kiểm tra cấu hình tên miền SMTP"

, "Confirm"
: "Xác nhận"

, "Do you really want to delete the selected tags?"
: "Bạn có muốn xóa các từ khóa đa chọn?"

, "Deleting tag(s)..."
: "Đang xóa từ khóa ..."

, "Add Tag"
: "Thêm từ khóa"

, "Edit Tag"
: "Sửa từ khóa"

, "Delete Tag"
: "Xóa từ khóa"

, "Search:"
: "Tìm kiếm:"

, "Displaying tags {0} - {1} of {2}"
: "Hiển thị từ khóa {0} - {1} của {2}"

, "No tags to display"
: "Không có từ khóa nào"

, "ID"
: "ID"

, "Color"
: "Màu"

, "Usage:&#160;"
: "Sử dụng:&#160;"

, "Do you really want to delete the selected roles?"
: "Bạn có muốn xóa vai trò đã chọn"

, "Deleting role(s)..."
: "Đang xóa vai trò..."

, "Failed"
: "Hỏng"

, "Some error occurred while trying to delete the role."
: "Có lỗi khi xóa vai trò"

, "Add Role"
: "Thêm vai trò"

, "Edit Role"
: "Sửa vai trò"

, "Delete Role"
: "Xóa vai trò"

, "Displaying roles {0} - {1} of {2}"
: "Hiển thị vai trò {0} - {1} của {2}"

, "No roles to display"
: "Không có vai trò nào"

, "Container Name"
: "Tên bộ chứa"

, "Type"
: "Loại"

, "Container Order"
: ""

, "Container, Containers"
: [
  "one: Bộ chứa\nother: Bộ chứa"

]
, "Model"
: "Model"

, "personal"
: "cá nhân"

, "shared"
: "dùng chung"

, "Order"
: "Xắp xếp"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Ghi chép cho chủ sở huwuxu"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Bạn có muốn xóa nhóm được chọn"

, "Deleting group(s)..."
: "Đang xóa nhóm ..."

, "Some error occurred while trying to delete the group."
: "Có lỗi xảy ra khi xóa nhóm"

, "Add Group"
: "Tạo nhóm"

, "Edit Group"
: "Sửa nhóm"

, "Delete Group"
: "Xóa nhóm"

, "Displaying groups {0} - {1} of {2}"
: "Hiển thị nhóm {0} - {1} của {2}"

, "No groups to display"
: "Không có nhóm bài được hiển thị"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "Địa chỉ IP"

, "Login Time"
: "Thời gian đăng nhập"

, "Logout Time"
: "Thời gian thoát"

, "Client Type"
: "Loại người dùng"

, "Session ID"
: "Session ID"

, "Login Name"
: "Tên đăng nhập"

, "Result"
: "Kết quả"

, "User Agent"
: ""

, "user blocked"
: "người dùng đã bị phong tỏa"

, "password expired"
: "mật khẩu đã hết hạn"

, "user disabled"
: "người dùng đã bị cấm"

, "invalid password"
: "sai mật khẩu"

, "ambiguous username"
: "Tên truy cập không rõ"

, "user not found"
: "không tìm thấy người dùng"

, "failure"
: "hỏng"

, "success"
: "thành công"

, "Customfield, Customfields"
: [
  "one: Trường tùy biến\nother: Trường tùy biến"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Lỗi"

, "Please configure store for this field type"
: "Xin cấu hình store cho loại trường này"

, "Record Class"
: "Record Class"

, "Given record class not found"
: "Lớp (class) biểu ghi đã cho không tồn tại"

, "Cancel"
: "Hủy"

, "OK"
: "OK"

, "Configure store"
: "Cấu hình store"

, "Custom field definition"
: "Định nghĩa trường tùy biến"

, "Text"
: "Chữ"

, "Textarea"
: ""

, "Number"
: "Số"

, "Date"
: "Ngày"

, "DateTime"
: "DateTime"

, "Time"
: "Time"

, "Boolean"
: "Boolean"

, "Search Combo"
: "Kết hợp tìm kiếm"

, "Key Field"
: "Trường chính"

, "Record"
: "Biểu ghi"

, "Record List"
: ""

, "Length"
: "Độ dài"

, "Required"
: "Yêu cầu"

, "Custom field additional properties"
: "Thuộc tính khác cho trường tùy biến"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "one: Nhóm\nother: Nhóm"

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: "Trường tùy biến đã tồn tại. Xin chọn tên khác."

, "Enable Account"
: "Mở tài khoản"

, "Disable Account"
: "Tắt tài khoản"

, "Reset Password"
: "Nhập lại mật khẩu"

, "Status"
: "Trạng thái"

, "Display name"
: "Tên hiển thị"

, "Login name"
: "Tên đăng nhập"

, "Last name"
: "Tên"

, "First name"
: "Tên họ"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Đăng nhập lần cuối lúc"

, "Last login from"
: "Đawng nhập lần cuối từ"

, "Password Must Change"
: "Mật khẩu phải được thay đổi"

, "Password changed"
: "Đã đổi mật khẩu"

, "Expires"
: "Hết hạn"

, "Set new password"
: "Đặt mật khẩu mới"

, "Please enter the new password:"
: "Xin hãy nhập mật khẩu mới"

, "Users"
: "Người dùng"

, "Samba User, Samba Users"
: [
  "one: Người dùng Samba\nother: Người dùng Samba"

]
, "Email User, Email Users"
: [
  "one: Người sử dụng email\nother: Người sử dụng email"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Mật khẩu không giống nhau"

, "Passwords match!"
: "Mật khẩu giống nhau"

, "Primary group"
: "Nhóm chính"

, "Unix"
: "Unix"

, "Home Directory"
: "Thư mục Home"

, "Login Shell"
: "Shell Login"

, "Windows"
: "Windows"

, "Home Drive"
: "Home Drive"

, "never logged in"
: "chưa bao giờ đăng nhập"

, "Home Path"
: "Đường dẫn trang chủ"

, "never logged off"
: "chưa bao giờ thoát"

, "Profile Path"
: "Đường dẫn hồ sơ"

, "Password Last Set"
: "Đặt mật khẩu lần cuối"

, "never"
: "chưa bao giờ"

, "Logon Script"
: "Script đăng nhập"

, "Password Can Change"
: "Mật khẩu có thể đổi"

, "not set"
: "chưa đặt"

, "Kick Off Time"
: "Thời gian bắt đầu"

, "Filesystem Quota"
: ""

, "Quota"
: "Quota"

, "no quota set"
: "chưa đặt quota"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Dung lượng Mailbox hiện tại"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Current Sieve size"

, "Information"
: "Thông tin"

, "Last Login"
: "Đăng nhập lần cuối"

, "Forward Only"
: "Chỉ chuyển tiếp"

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Thêm 1 địa chỉ ánh xạ email..."

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: "Tên miền không được phép sử dụng"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: "Chuyển tiếp tới chính tôi"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "Xác nhận mật khẩu"

, "Repeat password"
: "Nhập lại mật khẩu"

, "Ok"
: "OK"

, "Account"
: "Tài khoản"

, "Password"
: "Mật khẩu"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "đang mở"

, "disabled"
: "đã tắt"

, "expired"
: "hết hạn"

, "blocked"
: "đã bị phong tỏa"

, "Invalid Status"
: "Trạng thái không hợp lệ"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Trạng thái bị phong tỏa chỉ hợp lệ khi người dùng cố đăng nhập với một mật khẩu sai một cách thường xuyên. Nó không thể được đặt trạng thái này ở đây."

, "don't know"
: "không biết"

, "Password set"
: "Mật khẩu được đặt"

, "User groups"
: "Nhóm người dùng"

, "User roles"
: "Vai trò người dùng"

, "Fileserver"
: "Máy chủ file"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "one: Máy tính\nother: Máy tính"

]
, "Please wait"
: "Xin hãy đợi"

, "Updating Memberships"
: "Đang cập nhật thành viên"

, "Could not save role."
: "Không thể lưu vai trò"

, "Please fix the errors noted."
: "Xin hãy sửa các lỗi được ghi chú."

, "Deleting role..."
: "Đang xóa vai trò ..."

, "Rights"
: "Quyền"

, "Members"
: "Thành viên"

, "Role Name"
: "Tên vai trò"

, "Transferring {0}..."
: "Đang chuyển {0} ..."

, "Role"
: "Vai trò"

, "Add New Role"
: "Thêm vai trò"

, "Edit Role \"{0}\""
: "Sửa vai trò \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Đang cập nhật từ khóa"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Ngữ cảnh được phép"

, "Context"
: "Ngữ cảnh"

, "Account Rights"
: "Quyền tài khoản"

, "View"
: "Xem"

, "Use"
: "Sử dụng"

, "Tag Name"
: "Tên từ khóa"

, "Tag"
: "Từ khóa"

, "Add New Tag"
: "Thêm từ khóa"

, "Edit Tag \"{0}\""
: "Sửa từ khóa \"{0}\""

, "Enable Application"
: "Mở ứng dụng"

, "Disable Application"
: "Cấm ứng dụng"

, "Settings"
: "Thiết lập"

, "{0} Settings"
: "{0} Thiết lập"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Hiển thị ứng dụng {0} - {1} của {2}"

, "No applications to display"
: "Không có ứng dụng nào"

, "Version"
: "Phiên bản"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: "Default IMAP user settings"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Bộ chứa của bạn đã được thay đổi"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Bộ chứa của bạn đã được đổi từ %1$s %2$s. Ghi chú: %3$s"

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""












































, "ImportExportDefinition"
: ""

, "Application"
: "one: Ứng dụng\nother: Ứng dụng"

, "User"
: "one: Người dùng\nother: Người dùng"

, "Access Log"
: "one: Nhật ký truy cập\nother: Nhật ký truy cập"

, "Config"
: ""

, "Container"
: "one: Bộ chứa\nother: Bộ chứa"

, "Customfield"
: "one: Trường tùy biến\nother: Trường tùy biến"

, "Group"
: "one: Nhóm\nother: Nhóm"

, "Samba User"
: "one: Người dùng Samba\nother: Người dùng Samba"

, "Email User"
: "one: Người sử dụng email\nother: Người sử dụng email"

, "Computer"
: "one: Máy tính\nother: Máy tính"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
